use serde::Serialize;

#[derive(Serialize, Debug)]
pub struct BoxPlot {}

#[derive(Serialize, Debug)]
pub struct Histogram {}

#[derive(Serialize, Debug)]
pub struct Density {}
